@@ -19,14 +19,15 @@ test_that("plot.HydeNetwork returns a plot with custom Node settings",
 test_that("HydePlotOptions",
 {
   expect_silent({
-    HydePlotOptions(variable=list(shape = "rect", fillcolor = "#A6DBA0"),
+    HydePlotOptions(variable = list(shape = "rect", fillcolor = "#A6DBA0"),
                   determ = list(shape = "rect", fillcolor = "#E7D4E8",
                                 fontcolor = "#1B7837", linecolor = "#1B7837"),
                   decision = list(shape = "triangle", fillcolor = "#1B7837",
                                   linecolor = "white"),
                   utility = list(shape = "circle", fillcolor = "#762A83", 
                                  fontcolor = "white"))
-    plot(BlackJack)})
+    plot(BlackJack)
+  })
 })
 
 test_that("HydePlotOptions - restoreDefaults",
